@@ -104,7 +104,7 @@ our @EXPORT = qw(
 
 );
 
-our $VERSION = '0.2.2';
+our $VERSION = '0.1';
 
 
 our $FEDORA_VERSION = "3.2";
@@ -336,7 +336,6 @@ sub ingest {
 
   } elsif ($ingest_result->fault && $self->{reload} && 
 	   $ingest_result->faultstring =~/already exists in the registry/) {
-    #
     $ingest_result->faultstring =~/The PID \'([^\']*)\' already/;
     ${$args{pid_ref}} = $1;
     if ($self->{debug}) {
@@ -394,9 +393,12 @@ sub createObject {
   my ($foxml_ref, $foxml_template_file, $pid);
   my (@temp_files) = ();
 
+  print "DELETE print below:\n";
+
   # Use in-line FOXML when defaul FOXML file is not present.
   if (! $args{XML_ref} && ($args{XML_file} && ! -s $args{XML_file})) {
     $args{XML_ref} = \$default_foxml;
+    print "Using default in-line FOXML\n";
   }
 
   if ($args{XML_ref}) {
@@ -429,6 +431,7 @@ sub createObject {
 
     if (! defined $template) {
       my $mes = "Failed to instantiate Fedora template.";
+#      print "SUB: Error: $mes\n";
       $self->{ERROR_MESSAGE} = "Failed to create FOXML template instance.";
       return 1;
     }
@@ -445,6 +448,7 @@ sub createObject {
       }
 
       foreach my $param (keys %params) {
+#	print "SUB: Perform template substitution: $param / $params{$param}\n";
 	$template->param($param => $params{$param});
       }
 
@@ -633,11 +637,25 @@ sub getNextPID {
 
   my @pids = $getnextpid_result->paramsout();
 
+#  print " PID: $result_ref\n";
   foreach my $p (@pids) {
+##    print "PIDs: $p\n";
     push @{$args{pidlist_ref}}, $p;
   }
 
+#  @pids = @{$getnextpid_result->result()};
+#  foreach my $p (@pids) {
+#    print "##PIDs: $p\n";
+#    push @pids, $p;
+##    push @{$args{pidlist_ref}}, $p;
+#  }
+
+#  $args{pidlist_ref} = \@pids;
+
+  # Handle success
+#  map { push @{$args{pidlist_ref}}, $_; } @{$result_ref};
   return 0;
+
 }
 
 
@@ -724,6 +742,7 @@ sub addDatastream {
   # Since many datastreams were added with the versionable flag set to
   # false we must change this using the setDatastreamVersionable APIM
   # request to make this active
+#  print "Set Datastream Versionable.\n";
   my $ts;
   if ($self->setDatastreamVersionable
       ( pid => $args{pid},
@@ -899,6 +918,7 @@ sub uploadNewDatastream {
 			      logMessage => $args{logMessage},
 			      dsid_ref => \$dsid ) == 0) {
 
+#      print "Added Datastream: $dsid to object: $args{pid}\n";
       ${$args{dsid_ref}} = $dsid;
       return 0;
     } else {
@@ -1317,6 +1337,7 @@ sub compareDatastreamChecksum {
       $compareChecksum_result->faultcode."; ".
 	$compareChecksum_result->faultstring."; ".
 	  $compareChecksum_result->faultdetail;
+    print "Checksum ERROR Result: $self->{ERROR_MESSAGE}\n";
     return 2;
   }
 
@@ -1325,6 +1346,7 @@ sub compareDatastreamChecksum {
   ${$args{checksum_result}} = $result_ref;
 
   if ($result_ref =~ /Checksum validation error/) {
+    print "Error: $result_ref\n";
     return 3;
   }
   return 0;
@@ -1349,7 +1371,8 @@ sub addRelationship {
   my $self = shift;
   my %args = @_;
 
-  $self->{ERROR_MESSAGE}=undef;  $self->{TIME}=undef;
+  $self->{ERROR_MESSAGE}=undef;
+  $self->{TIME}=undef;
 
   Carp::croak "Parameter 'pid' missing" unless defined($args{pid});
   Carp::croak "Parameter 'relationship' missing" unless defined($args{relationship});
@@ -1370,7 +1393,9 @@ sub addRelationship {
       $args{pid},
       $args{relationship},
       $args{object},
+##      $args{isLiteral},
       SOAP::Data->value($args{isLiteral})->type('xsd:boolean'),
+#      SOAP::Data->value($args{versionable})->type('xsd:boolean'),
       $args{datatype},
     );
     my $elapse_time = time - $start;
@@ -1396,7 +1421,7 @@ sub addRelationship {
   ${$args{result}} = $arel_result->result();
 
   if ( $arel_result->result() eq 'false') {
-    # Assume that the relation exists already. If we are supporting
+    # Assume that the relation exists already. IF we are supporting
     # reloads then we must deal with this error even if it indicates 
     # that the relation already exists.
     if ($self->{reload}) {
@@ -1411,44 +1436,13 @@ sub addRelationship {
 				    datatype => $args{datatype},
 				    result => \$result,
 				  ) == 0) {
+	print "X-Purge Relation Successfully: $result\n";
       } else {
-	my $msg = $self->{ERROR_MESSAGE} || "";
-	$self->{ERROR_MESSAGE}="purgeRelationship failed:" . $msg;
-	return 2;
+	print "X-Purge Relationship failed: " . $self->error() . "\n";
       }
-      # Now add the relationship
-      my $arel_result;
-      eval {
-	my $start=time;
-	$arel_result = $self->{apim}->addRelationship
-	  (
-	   $args{pid},
-	   $args{relationship},
-	   $args{object},
-	   SOAP::Data->value($args{isLiteral})->type('xsd:boolean'),
-	   $args{datatype},
-	  );
-	my $elapse_time = time - $start;
-	$self->{TIME} = $elapse_time;
-	$self->{STAT}->{'addRelation'}{count}++;
-	$self->{STAT}->{'addRelation'}{time} += $elapse_time;
-      };
-      if ($@) {
-	$self->{ERROR_MESSAGE}=$self->_handle_exceptions($@);
-	return 1; 
-      }
-      if ($arel_result->result() eq 'false') {
-	return 2;
-      } else {
-	return 0;
-      }
-    } else { # AddRelationship failed and Reload flag not set
-      my $msg = $self->{ERROR_MESSAGE} || "";
-      $msg = $arel_result->faultcode."; ".
-	$arel_result->faultstring."; ".
-	  $arel_result->faultdetail;
-      $self->{ERROR_MESSAGE}="addRelationship failed (may exist already):"
-	. $msg;
+      return 0;
+    } else {
+      $self->{ERROR_MESSAGE}="addRelationship failed (may exist already).";
       return 2;
     }
     return 2;
@@ -1507,7 +1501,7 @@ sub getRelationships {
 
   # Handle success
   ${$args{result_ref}} = $grel_result->result();
-
+print "RESULT:\n" . $grel_result->result() . "\n";
   return 0;
 }
 
@@ -2037,7 +2031,7 @@ are normally used together in client code into a single method.
 
 =item createObject()
 
-This method takes care of creating the FOXML and the new object [normally two APIM steps].
+This method takes care of creating the FOXML and the new object [normally two APIA steps].
 
 Creating an object requires FOXML for the object you are creating.
 You must install the default ingest template (available) in the 
@@ -2056,7 +2050,7 @@ Typical createObject() method call:
       XML_file=> "./ingesttemplate.xml", 
       params => { pid_in => $idno,
                   title_in => "$title",
-                  collection_in => "$collection"},
+                  collection_in => "DXLS:Math"},
       pid_ref =>\$pid 
     );
 
@@ -2065,7 +2059,7 @@ To use default ingest template:
     $apim->createObject (
       params => { pid_in => $idno,
                   title_in => "$title",
-                  collection_in => "$collection"},
+                  collection_in => "DXLS:Math"},
       pid_ref =>\$pid 
 
 To specify FOXML template that's already stored in memory:
@@ -2074,7 +2068,7 @@ To specify FOXML template that's already stored in memory:
       XML_ref => "$foxml",
       params => { pid_in => $idno,
                   title_in => "$title",
-                  collection_in => "$collection"},
+                  collection_in => "DXLS:Math"},
       pid_ref =>\$pid 
 
 =item uploadNewDatastream()
@@ -2186,7 +2180,7 @@ parameters to the wrapping method.
 Fedora documentation: L<http://fedora-commons.org/confluence/display/FCR30/Fedora+Repository+3.2.1+Documentation>.
 
 Fedora API-M documentation:
-L<http://www.fedora-commons.org/confluence/display/FCR30/API-M>.
+L<http://www.fedora.info/definitions/1/0/api/Fedora-API-M.html>.
 
 =head1 AUTHOR
 
